@@ -32,13 +32,13 @@ def _on_connect(client, userdata, flags, rc):
     elif str(rc)=="4":
         print("\n连接结果: 错误的用户名或密码 ")
     else:
-        print("\n连接结果: 未经授权 ") 
+        print("\n连接结果: 未经授权 "+str(rc)) 
 
 def _on_disconnect(client, userdata, rc):
     if rc == 0:
         print("\n连接结果: 断开成功 ")
     else:
-        print("\n网络受限 ") 
+        print("\n网络受限 "+str(rc)) 
 
 def init(client_id, server, port=1883, user=None, password=None, cb1=_on_connect, cb2=_on_disconnect):
     global _host, _port, _user, _password, client
@@ -76,7 +76,7 @@ def _on_disconnect(client, userdata, rc):
     elif str(rc)=="4":
         print("\n连接结果: 错误的用户名或密码 ")
     else:
-        print("\n连接结果: 未经授权 ") 
+        print("\n连接结果: 未经授权 "+str(rc)) 
 
 def set_callback(cb):
     client.on_message = cb
